@@ -2,9 +2,9 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2008-2012 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2008-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-kajongg is free software you can redistribute it and/or modify
+Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation either version 2 of the License, or
 (at your option) any later version.
@@ -20,41 +20,43 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
 # keyboardinterrupt should simply terminate
-import signal
-signal.signal(signal.SIGINT, signal.SIG_DFL)
-import sys
+#import signal
+#signal.signal(signal.SIGINT, signal.SIG_DFL)
+import sys, logging
 
-from PyQt4.QtCore import QObject, QEvent, Qt
-from about import About
+from qt import QObject, usingQt4
 from kde import ki18n, KApplication, KCmdLineArgs, KCmdLineOptions
+from about import About
 
 from common import Options, SingleshotOptions, Internal, Debug
+from util import kprint
 
 # do not import modules using twisted before our reactor is running
-# do not import util directly or indirectly before Internal.app
-# is set
 
 def initRulesets():
     """exits if user only wanted to see available rulesets"""
     import predefined # pylint: disable=unused-variable
     if Options.showRulesets or Options.rulesetName:
         from rule import Ruleset
-        from util import kprint
-        from query import DBHandle
-        rulesets = Ruleset.selectableRulesets()
+        rulesets = dict((x.name, x) for x in Ruleset.selectableRulesets())
         if Options.showRulesets:
-            for ruleset in rulesets:
-                kprint(ruleset.name)
-            DBHandle.default = None
+            for name in rulesets:
+                kprint(name)
+            Internal.db.close()
             sys.exit(0)
+        elif Options.rulesetName in rulesets:
+            # we have an exact match
+            Options.ruleset = rulesets[Options.rulesetName]
         else:
-            for ruleset in rulesets:
-                if ruleset.name == Options.rulesetName:
-                    Options.ruleset = ruleset
-                    break
-            else:
-                DBHandle.default = None
-                raise SystemExit('Ruleset %s is unknown' % Options.rulesetName)
+            matches = list(x for x in rulesets if Options.rulesetName in x)
+            if len(matches) != 1:
+                if len(matches) == 0:
+                    msg = 'Ruleset %s is unknown' % Options.rulesetName
+                else:
+                    msg = 'Ruleset %s is ambiguous: %s' % (Options.rulesetName, ', '.join(matches))
+                Internal.db.close()
+                raise SystemExit(msg)
+            Options.ruleset = rulesets[matches[0]]
 
 def defineOptions():
     """this is the KDE way. Compare with kajonggserver.py"""
@@ -65,12 +67,16 @@ def defineOptions():
     options.add("table <TABLE>", ki18n("start new TABLE"))
     options.add("join <TABLE>", ki18n("join TABLE "))
     options.add("ruleset <RULESET>", ki18n("use ruleset without asking"))
+    options.add("rounds <ROUNDS>", ki18n("play one ROUNDS rounds per game. Only for debugging!"))
     options.add("player <PLAYER>", ki18n("prefer PLAYER for next login"))
     options.add("ai <AI>", ki18n("use AI variant for human player in demo mode"))
     options.add("csv <CSV>", ki18n("write statistics to CSV"))
     options.add("rulesets", ki18n("show all available rulesets"))
-    options.add("game <seed/hand/discard>", ki18n("for testing purposes: Initializes the random generator"), "0")
+    options.add("game <seed(/(firsthand)(..(lasthand))>",
+        ki18n("for testing purposes: Initializes the random generator"), "0")
     options.add("nogui", ki18n("show no graphical user interface. Intended only for testing"))
+    options.add("nokde", ki18n("Do not use KDE bindings. Intended only for testing"))
+    options.add("qt5", ki18n("Force using Qt5. Currently Qt4 is used by default"))
     options.add("socket <SOCKET>", ki18n("use a dedicated server listening on SOCKET. Intended only for testing"))
     options.add("debug <OPTIONS>", ki18n(Debug.help()))
     return options
@@ -80,12 +86,14 @@ def parseOptions():
     args = KCmdLineArgs.parsedArgs()
     Internal.app = APP
     Options.playOpen |= args.isSet('playopen')
-    Options.showRulesets|= args.isSet('rulesets')
+    Options.showRulesets |= args.isSet('rulesets')
     Options.rulesetName = str(args.getOption('ruleset'))
     if args.isSet('host'):
         Options.host = str(args.getOption('host'))
     if args.isSet('player'):
         Options.player = str(args.getOption('player'))
+    if args.isSet('rounds'):
+        Options.rounds = str(args.getOption('rounds'))
     if args.isSet('ai'):
         Options.AI = str(args.getOption('ai'))
     if args.isSet('csv'):
@@ -103,7 +111,8 @@ def parseOptions():
     Internal.autoPlay = Options.demo
     msg = Debug.setOptions(str(args.getOption('debug')))
     if msg:
-        print msg
+        Internal.logger.debug(msg)
+        logging.shutdown()
         sys.exit(2)
     from query import initDb
     if not initDb():
@@ -113,39 +122,21 @@ def parseOptions():
 
 class EvHandler(QObject):
     """an application wide event handler"""
-    events = {y:x for x, y in QEvent.__dict__.items() if isinstance(y, int)}
-    keys = {y:x for x, y in Qt.__dict__.items() if isinstance(y, int)}
+
     def eventFilter(self, receiver, event):
         """will be called for all events"""
-        from util import logDebug
-        if event.type() in self.events:
-            # ignore unknown event types
-            name = self.events[event.type()]
-            if 'all' in Debug.events or name in Debug.events:
-                if hasattr(event, 'key'):
-                    value = self.keys[event.key()]
-                elif hasattr(event, 'text'):
-                    value = str(event.text())
-                else:
-                    value = ''
-                if value:
-                    value = '(%s)' % value
-                msg = '%s%s->%s' % (name, value, receiver)
-                if hasattr(receiver, 'text'):
-                    msg += '(%s)' % receiver.text()
-                elif hasattr(receiver, 'objectName'):
-                    msg += '(%s)' % receiver.objectName()
-                logDebug(msg)
+        from log import EventData
+        EventData(receiver, event)
         return QObject.eventFilter(self, receiver, event)
 
 if __name__ == "__main__":
-    from util import initLog
-    initLog('kajongg')
+    from util import gitHead
 
     ABOUT = About()
-    KCmdLineArgs.init (sys.argv, ABOUT.about)
+    KCmdLineArgs.init(sys.argv, ABOUT.about)
     KCmdLineArgs.addCmdLineOptions(defineOptions())
-    KApplication.setGraphicsSystem('raster')
+    if usingQt4:
+        KApplication.setGraphicsSystem('raster')
     APP = KApplication()
     parseOptions()
 
@@ -156,16 +147,10 @@ if __name__ == "__main__":
     from config import SetupPreferences
     SetupPreferences()
 
-    import qt4reactor
-    qt4reactor.install()
-    from twisted.internet import reactor
-    reactor.runReturn(installSignalHandlers=False)
-    Internal.reactor = reactor
-
-    if Options.gui:
-        from playfield import PlayField
-        PlayField().show()
-    else:
-        from humanclient import HumanClient
-        HumanClient()
+    if Options.csv:
+        if gitHead() == 'current':
+            Internal.logger.debug('You cannot write to %s with changes uncommitted to git' % Options.csv)
+            sys.exit(2)
+    from mainwindow import MainWindow
+    MainWindow()
     Internal.app.exec_()
