@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2010-2012 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2010-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-kajongg is free software you can redistribute it and/or modify
+Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation either version 2 of the License, or
 (at your option) any later version.
@@ -20,12 +20,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 import datetime
 
-from util import m18n, m18nc, m18ncE, logWarning, logException, logDebug
+from log import m18n, m18nc, m18ncE, logWarning, logException, logDebug
 from sound import Voice, Sound
-from tile import Tile
-from meld import Meld
+from tile import Tile, TileList
+from meld import Meld, MeldList
 from common import Internal, Debug
-from kde import Sorry
+from dialogs import Sorry
 
 # pylint: disable=super-init-not-called
 # multiple inheritance: pylint thinks ServerMessage.__init__ does not get called.
@@ -48,7 +48,7 @@ class Message(object):
         Message.defined[self.name] = self
         className = self.__class__.__name__.replace('Message', '')
         msgName = self.name.replace(' ', '')
-        assert className ==  msgName, '%s != %s' % ( className, msgName)
+        assert className == msgName, '%s != %s' % (className, msgName)
 
     def __str__(self):
         return self.name
@@ -62,10 +62,8 @@ class Message(object):
         pb.Copyable is too much overhead"""
         # pylint: disable=too-many-return-statements
         cls = value.__class__
-        if cls == Tile:
+        if cls in (Tile, TileList, Meld, MeldList):
             return str(value)
-        elif cls == Meld:
-            return value.joined
         elif isinstance(value, Message):
             return value.name
         elif isinstance(value, (list, tuple)):
@@ -152,7 +150,10 @@ class NotifyAtOnceMessage(ClientMessage):
         player who triggered us"""
         # default: tell all except the source of the notification
         game = request.block.table.game
-        return list(x for x in game.players if x != request.player)
+        if game:
+            return list(x for x in game.players if x != request.player)
+        else:
+            return []
 
 class PungChowMessage(NotifyAtOnceMessage):
     """common code for Pung and Chow"""
@@ -161,19 +162,19 @@ class PungChowMessage(NotifyAtOnceMessage):
 
     def toolTip(self, button, dummyTile):
         """decorate the action button which will send this message"""
-        maySay = button.client.sayable[self]
+        myself = button.client.game.myself
+        maySay = myself.sayable[self]
         if not maySay:
             return '', False, ''
-        myself = button.client.game.myself
         txt = []
         warn = False
         if myself.originalCall and myself.mayWin:
             warn = True
             txt.append(m18n('saying %1 violates Original Call',
                 self.i18nName))
-        dangerousMelds = button.client.maybeDangerous(self)
+        dangerousMelds = myself.maybeDangerous(self)
         if dangerousMelds:
-            lastDiscard = button.client.game.lastDiscard
+            lastDiscard = myself.game.lastDiscard
             warn = True
             if Debug.dangerousGame and len(dangerousMelds) != len(maySay):
                 button.client.game.debug('only some claimable melds are dangerous: %s' % dangerousMelds)
@@ -194,7 +195,7 @@ class MessagePung(PungChowMessage, ServerMessage):
     """somebody said pung and gets the tile"""
     def __init__(self):
         PungChowMessage.__init__(self,
-            name=m18ncE('kajongg','Pung'),
+            name=m18ncE('kajongg', 'Pung'),
             shortcut=m18ncE('kajongg game dialog:Key for Pung', 'P'))
     def serverAction(self, table, msg):
         """the server mirrors that and tells all others"""
@@ -207,20 +208,20 @@ class MessageKong(NotifyAtOnceMessage, ServerMessage):
     """somebody said kong and gets the tile"""
     def __init__(self):
         NotifyAtOnceMessage.__init__(self,
-            name=m18ncE('kajongg','Kong'),
+            name=m18ncE('kajongg', 'Kong'),
             shortcut=m18ncE('kajongg game dialog:Key for Kong', 'K'))
     def serverAction(self, table, msg):
         """the server mirrors that and tells all others"""
         if table.game.lastDiscard:
             table.claimTile(msg.player, self, msg.args[0], Message.Kong)
         else:
-            table.declareKong(msg.player, msg.args[0])
+            table.declareKong(msg.player, Meld(msg.args[0]))
     def toolTip(self, button, dummyTile):
         """decorate the action button which will send this message"""
-        maySay = button.client.sayable[self]
+        myself = button.client.game.myself
+        maySay = myself.sayable[self]
         if not maySay:
             return '', False, ''
-        myself = button.client.game.myself
         txt = []
         warn = False
         if myself.originalCall and myself.mayWin:
@@ -240,7 +241,7 @@ class MessageChow(PungChowMessage, ServerMessage):
     """somebody said chow and gets the tile"""
     def __init__(self):
         PungChowMessage.__init__(self,
-            name=m18ncE('kajongg','Chow'),
+            name=m18ncE('kajongg', 'Chow'),
             shortcut=m18ncE('kajongg game dialog:Key for Chow', 'C'))
     def serverAction(self, table, msg):
         """the server mirrors that and tells all others"""
@@ -265,7 +266,7 @@ class MessageMahJongg(NotifyAtOnceMessage, ServerMessage):
     sendScore = True
     def __init__(self):
         NotifyAtOnceMessage.__init__(self,
-            name=m18ncE('kajongg','Mah Jongg'),
+            name=m18ncE('kajongg', 'Mah Jongg'),
             shortcut=m18ncE('kajongg game dialog:Key for Mah Jongg', 'M'))
     def serverAction(self, table, msg):
         """the server mirrors that and tells all others"""
@@ -275,14 +276,14 @@ class MessageMahJongg(NotifyAtOnceMessage, ServerMessage):
         return m18n('Press here and you win'), False, ''
     def clientAction(self, dummyClient, move):
         """mirror the mahjongg action locally. Check if the balances are correct."""
-        return move.player.declaredMahJongg(move.source, move.withDiscardTile,
+        return move.player.declaredMahJongg(move.melds, move.withDiscardTile,
             move.lastTile, move.lastMeld)
 
 class MessageOriginalCall(NotifyAtOnceMessage, ServerMessage):
     """somebody made an original call"""
     def __init__(self):
         NotifyAtOnceMessage.__init__(self,
-            name=m18ncE('kajongg','Original Call'),
+            name=m18ncE('kajongg', 'Original Call'),
             shortcut=m18ncE('kajongg game dialog:Key for Original Call', 'O'))
     def serverAction(self, table, msg):
         """the server tells all others"""
@@ -291,7 +292,7 @@ class MessageOriginalCall(NotifyAtOnceMessage, ServerMessage):
         """decorate the action button which will send this message"""
         assert isinstance(tile, Tile), tile
         myself = button.client.game.myself
-        isCalling = bool((myself.hand - tile).callingHands())
+        isCalling = bool((myself.hand - tile).callingHands)
         if not isCalling:
             txt = m18n('discarding %1 and declaring Original Call makes this hand unwinnable',
                 tile.name())
@@ -317,7 +318,7 @@ class MessageDiscard(ClientMessage, ServerMessage):
  #   sendScore = True
     def __init__(self):
         ClientMessage.__init__(self,
-            name=m18ncE('kajongg','Discard'),
+            name=m18ncE('kajongg', 'Discard'),
             shortcut=m18ncE('kajongg game dialog:Key for Discard', 'D'))
     def serverAction(self, table, msg):
         """the server mirrors that action"""
@@ -341,7 +342,7 @@ class MessageDiscard(ClientMessage, ServerMessage):
         return txt, warn, txt
     def clientAction(self, client, move):
         """execute the discard locally"""
-        if client.isHumanClient() and Internal.field:
+        if client.isHumanClient() and Internal.scene:
             move.player.handBoard.setEnabled(False)
         move.player.speak(move.tile)
         return client.game.hasDiscarded(move.player, move.tile)
@@ -370,6 +371,11 @@ class MessageReadyForGameStart(ServerMessage):
         """ask the client"""
         def hideTableList(result):
             """hide it only after player says I am ready"""
+            # set scene.game first, otherwise tableList.hide()
+            # sees no current game and logs out
+            if result == Message.OK:
+                if client.game and Internal.scene:
+                    Internal.scene.game = client.game
             if result == Message.OK and client.tableList and client.tableList.isVisible():
                 if Debug.table:
                     logDebug('%s hiding table list because game started' % client.name)
@@ -407,12 +413,12 @@ class MessageInitHand(ServerMessage):
         """prepare a new hand"""
         client.game.divideAt = move.divideAt
         client.game.wall.divide()
-        if hasattr(client,'shutdownHumanClients'):
+        if hasattr(client, 'shutdownHumanClients'):
             client.shutdownHumanClients(exception=client)
-        field = Internal.field
-        if field:
-            field.setWindowTitle(m18n('Kajongg <numid>%1</numid>', client.game.handId()))
-            field.discardBoard.setRandomPlaces(client.game.randomGenerator)
+        scene = Internal.scene
+        if scene:
+            scene.mainWindow.setWindowTitle(m18n('Kajongg <numid>%1</numid>', client.game.handId.seed))
+            scene.discardBoard.setRandomPlaces(client.game.randomGenerator)
         client.game.initHand()
 
 class MessageSetConcealedTiles(ServerMessage):
@@ -448,7 +454,7 @@ class MessagePickedTile(ServerMessage):
         assert move.player.pickedTile(move.deadEnd, tileName=move.tile) == move.tile, \
             (move.player.lastTile, move.tile)
         if client.thatWasMe(move.player):
-            if move.tile.isBonus():
+            if move.tile.isBonus:
                 return Message.Bonus, move.tile
             else:
                 return client.myAction(move)
@@ -529,13 +535,13 @@ class MessageDeclaredKong(ServerMessage):
         """mirror the action locally"""
         prompts = None
         if not client.thatWasMe(move.player):
-            if len(move.tiles) != 4 or move.tiles[0].istitle():
+            if len(move.meld) != 4 or move.meld[0].isConcealed:
                 # do not do this when adding a 4th tile to an exposed pung
-                move.player.showConcealedTiles(move.tiles)
+                move.player.showConcealedTiles(move.meld)
             else:
-                move.player.showConcealedTiles(move.tiles[3:4])
+                move.player.showConcealedTiles(move.meld[3])
             prompts = [Message.NoClaim, Message.MahJongg]
-        move.exposedMeld = move.player.exposeMeld(move.tiles)
+        move.exposedMeld = move.player.exposeMeld(move.meld)
         if prompts:
             return client.ask(move, prompts)
 
@@ -544,10 +550,9 @@ class MessageRobbedTheKong(NotifyAtOnceMessage, ServerMessage):
     def clientAction(self, client, move):
         """mirror the action locally"""
         prevMove = client.game.lastMoves(only=[Message.DeclaredKong]).next()
-        prevKong = Meld(prevMove.tiles)
-        prevMove.player.robTile(prevKong[0].upper())
+        prevMove.player.robTile(prevMove.meld[0].concealed)
         move.player.lastSource = 'k'
-        client.game.addCsvTag('robbedKong', forAllPlayers=True)
+        client.game.addCsvTag('robbedKong%s' % prevMove.meld[1], forAllPlayers=True)
 
 class MessageCalling(ServerMessage):
     """the game server tells us who announced a calling hand"""
@@ -581,8 +586,7 @@ class MessageNoChoice(ServerMessage):
         move.player.showConcealedTiles(move.tiles)
         # otherwise we have a visible artifact of the discarded tile.
         # Only when animations are disabled. Why?
-        if Internal.field:
-            Internal.field.centralView.resizeEvent(None)
+#        Internal.mainWindow.centralView.resizeEvent(None)
         return client.ask(move, [Message.OK]).addCallback(self.hideConcealedAgain)
 
     def hideConcealedAgain(self, result):
@@ -618,7 +622,7 @@ class MessageOK(ClientMessage):
     """a client says OK"""
     def __init__(self):
         ClientMessage.__init__(self,
-            name=m18ncE('kajongg','OK'),
+            name=m18ncE('kajongg', 'OK'),
             shortcut=m18ncE('kajongg game dialog:Key for OK', 'O'))
     def toolTip(self, dummyButton, dummyTile):
         """returns text and warning flag for button and text for tile for button and text for tile"""
@@ -628,7 +632,7 @@ class MessageNoClaim(NotifyAtOnceMessage, ServerMessage):
     """A player explicitly says he will not claim a tile"""
     def __init__(self):
         NotifyAtOnceMessage.__init__(self,
-            name=m18ncE('kajongg','No Claim'),
+            name=m18ncE('kajongg', 'No Claim'),
             shortcut=m18ncE('kajongg game dialog:Key for No claim', 'N'))
     def toolTip(self, dummyButton, dummyTile):
         """returns text and warning flag for button and text for tile for button and text for tile"""
@@ -652,7 +656,7 @@ def __scanSelf():
                         try:
                             msg = glob()
                         except Exception:
-                            print('cannot instantiate %s' % glob.__name__)
+                            logDebug('cannot instantiate %s' % glob.__name__)
                             raise
                         type.__setattr__(Message, msg.name.replace(' ', ''), msg)
 
