@@ -6,9 +6,9 @@ Authors of original libkmahjongg in C++:
     Copyright (C) 2006 Mauricio Piacentini <mauricio@tabuleiro.com>
 
 this adapted python code:
-    Copyright (C) 2008-2012 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+    Copyright (C) 2008-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-    kajongg is free software you can redistribute it and/or modify
+    Kajongg is free software you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation either version 2 of the License, or
     (at your option) any later version.
@@ -23,11 +23,10 @@ this adapted python code:
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
-from PyQt4.QtCore import QString, QVariant, QSizeF
-from PyQt4.QtSvg import QSvgRenderer
-from kde import KGlobal, KStandardDirs, KConfig, KConfigGroup
-from util import logWarning, logException, m18n
-from common import LIGHTSOURCES, Internal, Preferences
+from qt import QString, QSizeF, QSvgRenderer
+from kde import KGlobal, KStandardDirs, KConfig
+from log import logWarning, logException, m18n
+from common import LIGHTSOURCES, Internal
 
 TILESETVERSIONFORMAT = 1
 
@@ -37,8 +36,11 @@ class TileException(Exception):
 
 def locateTileset(which):
     """locate the file with a tileset"""
-    return QString(KStandardDirs.locate("kmahjonggtileset",
-                QString(which)))
+    path = KStandardDirs.locate("kmahjonggtileset", QString(which))
+    if path is None:
+        logException(TileException('cannot find kmahjonggtileset %s' % \
+                        (which)))
+    return QString(path)
 
 class Tileset(object):
     """represents a complete tileset"""
@@ -50,7 +52,7 @@ class Tileset(object):
         """whatever this does"""
         if not Tileset.catalogDefined:
             KGlobal.dirs().addResourceType("kmahjonggtileset",
-                "data", QString.fromLatin1("kmahjongglib/tilesets"))
+                "data", QString("kmahjongglib/tilesets"))
             KGlobal.locale().insertCatalog("libkmahjongglib")
             Tileset.catalogDefined = True
 
@@ -95,29 +97,29 @@ class Tileset(object):
             self.desktopFileName = desktopFileName
         self.darkenerAlpha = 120 if self.desktopFileName == 'jade' else 50
         tileconfig = KConfig(self.path, KConfig.SimpleConfig)
-        group = KConfigGroup(tileconfig.group("KMahjonggTileset"))
+        group = tileconfig.group("KMahjonggTileset")
 
-        self.name = group.readEntry("Name", "unknown tileset").toString() # Returns translated data
-        self.author = group.readEntry("Author", "unknown author").toString()
-        self.description = group.readEntry("Description", "no description available").toString()
-        self.authorEmail = group.readEntry("AuthorEmail", "no E-Mail address available").toString()
+        self.name = group.readEntry("Name") or m18n("unknown tileset")
+        self.author = group.readEntry("Author") or m18n("unknown author")
+        self.description = group.readEntry("Description") or m18n("no description available")
+        self.authorEmail = group.readEntry("AuthorEmail") or m18n("no E-Mail address available")
 
         #Version control
-        tileversion, entryOK = group.readEntry("VersionFormat", QVariant(0)).toInt()
+        tileversion = int(group.readEntry("VersionFormat")) or 0
         #Format is increased when we have incompatible changes, meaning that
         # older clients are not able to use the remaining information safely
-        if not entryOK or tileversion > TILESETVERSIONFORMAT:
+        if tileversion > TILESETVERSIONFORMAT:
             logException(TileException('tileversion file / program: %d/%d' % \
                 (tileversion, TILESETVERSIONFORMAT)))
 
-        graphName = QString(group.readEntry("FileName"))
+        graphName = group.readEntry("FileName")
         self.__graphicspath = locateTileset(graphName)
         if self.__graphicspath.isEmpty():
             logException(TileException('cannot find kmahjongglib/tilesets/%s for %s' % \
-                        (graphName, self.desktopFileName )))
+                        (graphName, self.desktopFileName)))
         self.renderer() # now that we get the sizes from the svg, we need the renderer right away
 
-        self.svgName = { 'wn': 'WIND_1', 'ws': 'WIND_2', 'we': 'WIND_3', 'ww': 'WIND_4',
+        self.svgName = {'wn': 'WIND_1', 'ws': 'WIND_2', 'we': 'WIND_3', 'ww': 'WIND_4',
             'db': 'DRAGON_1', 'dg': 'DRAGON_2', 'dr': 'DRAGON_3'}
         for value in '123456789':
             self.svgName['s%s' % value] = 'ROD_%s' % value
@@ -165,7 +167,7 @@ class Tileset(object):
 
     def shadowOffsets(self, lightSource, rotation):
         """real offset of the shadow on the screen"""
-        if not Preferences.showShadows:
+        if not Internal.Preferences.showShadows:
             return (0, 0)
         lightSourceIndex = LIGHTSOURCES.index(lightSource)
         return self.__shadowOffsets[lightSourceIndex][rotation//90]
